"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@angular-devkit/core");
const schematics_1 = require("@angular-devkit/schematics");
const tasks_1 = require("@angular-devkit/schematics/tasks");
const package_1 = require("../utils/package");
const libs_version_1 = require("../utils/libs-version");
const config_1 = require("@schematics/angular/utility/config");
const npm_script_1 = require("../utils/npm-script");
const project_1 = require("../utils/project");
function add(options) {
    return schematics_1.chain([
        install(),
        configure(options),
        main(),
    ]);
}
exports.default = add;
function install() {
    return (host, context) => {
        package_1.addPackageToPackageJson(host, 'devDependencies', 'angular-playground', libs_version_1.playgroundVersion);
        npm_script_1.addNpmScriptToPackageJson(host, 'playground', 'angular-playground');
        context.addTask(new tasks_1.NodePackageInstallTask());
        return host;
    };
}
exports.install = install;
function addAppToWorkspaceFile(options, workspace, projectRoot, packageName) {
    const normalizedProjectRoot = core_1.normalize(projectRoot === '' ? '' : `${projectRoot}/`);
    const project = {
        root: `${projectRoot}`,
        sourceRoot: `${normalizedProjectRoot}src`,
        projectType: 'application',
        architect: {
            build: {
                builder: '@angular-devkit/build-angular:browser',
                options: {
                    outputPath: `${normalizedProjectRoot}dist/playground`,
                    index: `${normalizedProjectRoot}src/index.html`,
                    main: `${normalizedProjectRoot}src/main.playground.ts`,
                    polyfills: `${normalizedProjectRoot}src/polyfills.ts`,
                    tsConfig: `${normalizedProjectRoot}src/tsconfig.app.json`,
                    assets: [
                        `${normalizedProjectRoot}src/favicon.ico`,
                        `${normalizedProjectRoot}src/asset`,
                    ],
                    styles: [
                        `${normalizedProjectRoot}src/styles.${options.stylesExtension}`,
                    ],
                    scripts: []
                },
                configurations: {
                    production: {
                        fileReplacements: [
                            {
                                replace: `${normalizedProjectRoot}src/environments/environment.ts`,
                                with: `${normalizedProjectRoot}src/environments/environment.prod.ts`,
                            }
                        ],
                        optimization: true,
                        outputHashing: 'all',
                        sourceMap: false,
                        extractCss: true,
                        namedChunks: false,
                        aot: false,
                        extractLicenses: true,
                        vendorChunk: false,
                        buildOptimizer: false
                    }
                }
            },
            serve: {
                builder: '@angular-devkit/build-angular:dev-server',
                options: {
                    browserTarget: 'playground:build',
                    port: 4201
                }
            }
        }
    };
    return config_1.addProjectToWorkspace(workspace, packageName, project);
}
function configure(options) {
    return (host, _context) => {
        const workspace = config_1.getWorkspace(host);
        const project = project_1.getProject(host, options);
        let stylesExtension = 'css';
        if (project.architect) {
            const mainStyle = project.architect.build.options.styles.find((path) => path.includes('/styles.'));
            if (mainStyle) {
                stylesExtension = mainStyle.split('.').pop();
            }
        }
        return schematics_1.chain([
            addAppToWorkspaceFile({ stylesExtension }, workspace, '', 'playground'),
        ])(host, _context);
    };
}
function main() {
    return schematics_1.branchAndMerge(schematics_1.mergeWith(schematics_1.url('./files')));
}
//# sourceMappingURL=index.js.map